@@ -1,7 +1,7 @@
 import enum
 import sys
 
-from typing import List, Optional, Tuple, Union, cast
+from typing import List, Optional, Tuple, TypeVar, Union, cast
 from typing_extensions import Literal
 
 
@@ -59,6 +59,12 @@ class TypeAnnotation:
             return TypeAnnotation(self.args[0])
         return None
 
+    def get_underlyings_if_union(self) -> List["TypeAnnotation"]:
+        if self.origin is Union:
+            return [TypeAnnotation(t) for t in self.args]
+        else:
+            return []
+
     def get_allowed_values_if_literal(self) -> Optional[Tuple[object, ...]]:
         if sys.version_info[:2] == (3, 6):
             # In Python 3.6 Literal must come from typing_extensions. However, it does not
@@ -175,3 +181,11 @@ def validate_value_against_type(
         raise TypeError(f"Failed to validate argument '{arg_name}': {error}")
 
     return value
+
+
+T = TypeVar("T")
+
+
+def assert_not_none(x: Optional[T]) -> T:
+    assert x is not None
+    return x
